@@ -19,6 +19,7 @@ type Application implements K8sObject {
   namespace: String
   app: JSON
   subscriptions: [JSON]
+  placement: JSON
 }
 
 type BasicApplication implements K8sObject {
@@ -55,6 +56,10 @@ type Subject {
   name: String
 }
 
+type ArgoServer {
+  argoServerNS: JSON
+}
+
 type Secret {
   ansibleSecretName: String
   ansibleSecretNamespace: String
@@ -64,10 +69,12 @@ type Secret {
 /* eslint-disable max-len */
 export const resolver = {
   Query: {
-    application: (root, args, { applicationModel }) => applicationModel.getApplication(args.name, args.namespace, ALL_SUBSCRIPTIONS, true),
+    application: (root, args, { applicationModel }) => applicationModel.getApplication(args.name, args.namespace, ALL_SUBSCRIPTIONS, true, undefined, args.apiversion),
     applications: (root, args, { applicationModel }) => applicationModel.getApplications(),
+    applicationSetRelatedResources: (root, args, { applicationModel }) => applicationModel.getApplicationSetRelatedResources(args.name, args.namespace),
     applicationNamespaces: (parent, args, { applicationModel }) => applicationModel.getApplicationNamespace(args.namespace),
     secrets: (root, args, { applicationModel }) => applicationModel.getSecrets(args),
+    argoServers: (root, args, { applicationModel }) => applicationModel.getArgoServerNs(),
     isManagedClusterConditionAvailable: (root, args, { applicationModel }) => applicationModel.getManagedCluster(args.clusterName),
     argoAppRouteURL: (root, args, { applicationModel }) => applicationModel.getArgoAppRouteURL(args),
     routeResourceURL: (root, args, { applicationModel }) => applicationModel.getRouteResourceURL(args),
