@@ -164,7 +164,7 @@ export const processDeployables = (
   // then the rest
   const other = _.remove(deployables, (obj) => {
     const kind = _.get(obj, templateKind, '');
-    return !_.includes(['Route', 'Ingress', 'Service', 'StatefulSet'], kind);
+    return !_.includes(['Route', 'Ingress', 'Service', 'StatefulSet', 'HelmRelease'], kind);
   });
 
   other.forEach((deployable) => {
@@ -212,7 +212,7 @@ export const getSubscriptionPackageInfo = (topoAnnotation, subscriptionName, app
           },
           spec: {
             template: {
-              apiVersion: 'apps/v1',
+              apiVersion: 'unknown',
               kind: deployableData[2],
               metadata: {
                 namespace,
@@ -399,6 +399,31 @@ export function buildArgoApplication(application, appName, appNamespace, nodes,
   });
 
   delete application.app.spec.apps;
+
+  // create placement node
+  const placement = _.get(application, 'placement', '');
+  if (placement) {
+    const { metadata: { name, namespace } } = placement;
+    const placementId = `member--placements--${namespace}--${name}`;
+    nodes.push({
+      name,
+      namespace,
+      type: 'placement',
+      id: placementId,
+      uid: placementId,
+      specs: {
+        isDesign: true,
+        raw: placement,
+      },
+    });
+    links.push({
+      from: { uid: appId },
+      to: { uid: placementId },
+      type: '',
+      specs: { isDesign: true },
+    });
+  }
+
   // create cluster node
   const clusterId = addClusters(
     appId, new Set(), null,
